# Brain Predictability Toolbox (BPt)

[![status](https://github.com/sahahn/BPt/actions/workflows/main.yml/badge.svg)](https://github.com/sahahn/BPt/actions) [![codecov](https://codecov.io/gh/sahahn/BPt/branch/master/graph/badge.svg?token=SCA77VAUAG)](https://codecov.io/gh/sahahn/BPt) ![version](https://img.shields.io/badge/python-3.7%20%7C%203.8%20%7C%203.9-blue) [![pip](https://badge.fury.io/py/brain-pred-toolbox.svg)](https://pypi.org/project/brain-pred-toolbox/) [![Downloads](https://static.pepy.tech/personalized-badge/brain-pred-toolbox?period=total&units=international_system&left_color=black&right_color=grey&left_text=Downloads)](https://pepy.tech/project/brain-pred-toolbox)


![logo](https://github.com/sahahn/BPt/blob/master/doc/source/_static/red_logo.png?raw=true)


- The Brain Predictability toolbox (BPt) is a Python based Machine Learning library designed for working with Neuroimaging data. This library is particularly suited towards working with large neuroimaging datasets, where a large number of subjects with potentially multi-modal data are available.

- Please check out the project documentation at:
<https://sahahn.github.io/BPt/>

- This library is based on python and likely will require atleast some prior experience with python and machine learning.


### Install
----

**Note:** *This library is only tested on python versions 3.7+ so while 3.6 might work, for the most reliable performance please use higher versions of python!*


The easiest way to install the latest stable release of BPt is via pip, just run
``` 
pip install brain-pred-toolbox 
```

The other method, to get the latest stable development version of the library is to clone this repository,
and then install it locally with once navigated into the main BPt folder

```
pip install .
```

